function [G, dGy, dGt] = baseline_evalhom(y,t,Q,N_star,N_hat,b_star,b_hat)

% Purpose - to evaulate the homotopy function based on current data

% Inputs:
% y - current data point on patch
% t - current time step value
% Q - random orthogonal matrix used for fixed randomization
% N_star - based on parameters for start system
% N_hat - based on parameters for target system
% b_star - based on parameters for start system and patching data
% b_hat - based on parameters for target system and patching data

% Set up system of equations for homotopy
N = N_star*t + N_hat*(1-t);
b = b_star*t + b_hat*(1-t);
temp = N*y + b;
E = [temp(1,1) temp(2,1) temp(3,1); ...
    temp(4,1) temp(5,1) temp(6,1); ...
    temp(7,1) temp(8,1) temp(9,1)];

% Evaluate system of equations for homotopy
[F, dF_E] = evalfunc(E);

% Set up homotopy function after randomization
G = [eye(3,3) Q]*F;
M = [eye(3,3) Q]*dF_E;

% Find derivatives of homotopy function
dGy = M*N;
dGt = M*((N_star - N_hat)*y + (b_star-b_hat));

return