function [Q, N_star, N_hat, b_star, b_hat] = baseline_setup(v)

% Purpose: to read in data for target and start systems.  The start data is
% from Bertini, whereas the target data can come from Bertini (commented
% out below) or be random (as is currently set up for testing).

% Input: 
% v - random patching data

% Target data from Bertini
% final_parameters = fopen('final_parameters','r');
% fscanf(final_parameters,'%d',1);
% p_hat_data = fscanf(final_parameters,'%e');
% fclose(final_parameters);
% p_hat_values = vec2mat(p_hat_data,2);
% p_hat_complex = p_hat_values(:,1) + p_hat_values(:,2)*1i;
% p_hat = vec2mat(p_hat_complex,9);

% Setting up random endpoint target parameters between -1 and 1
p_hat = rand(5,9)*2 - 1;

% Read in info. from Bertini run - will include known system info.
% Have: p_star, A(p_star), N_star, b_star
parameters = fopen('start_parameters','r');
fscanf(parameters,'%d',1);
p_star_data = fscanf(parameters,'%e');
fclose(parameters);
p_star_values = vec2mat(p_star_data,2);
p_star_complex = p_star_values(:,1) + p_star_values(:,2)*1i;
p_star = vec2mat(p_star_complex,9);

% Development of data from parameters for homotopy equation setup
mat_zero = zeros(5,1);
N_star = null([p_star; v]);
b_star = [p_star; v]\[mat_zero;1];
N_hat = null([p_hat; v]);
b_hat = [p_hat; v]\[mat_zero;1];

% Use QR factorization of a random matrix to find a 
% unitary, orthogonal matrix Q for fixed randomization
B = rand(6,3);
[Q,~] = qr(B,0);
Q = Q';

return