function [G, dGy, dGt] = leverage_local_evalhom(y,t,N_star,N_hat,c,Rand)

% Purpose - to evaulate the homotopy function based on current data

% Inputs:
% y - current data point on patch
% t - current time step value
% N_star - based on parameters for start system
% N_hat - based on parameters for target system
% c - indice for entry of patch vector that is 1
% Rand - leverage score randomization matrix used for homotopy

% Set up A matrix to ignore information from entry with value 1 (from
% patching)
A = eye(4,4);
A = A(:,[1:c-1,c+1:end]);
b = zeros(4,1);
b(c) = 1;

% Set up system of equations for homotopy
N = (N_star*t + N_hat*(1-t))*A;
temp = N*y + (N_star*t + N_hat*(1-t))*b;
E = [temp(1,1) temp(2,1) temp(3,1); ...
    temp(4,1) temp(5,1) temp(6,1); ...
    temp(7,1) temp(8,1) temp(9,1)];

% Evaluate system of equations for homotopy
[F, dF_E] = evalfunc(E);

% Set up homotopy function after randomization
G = Rand*F;
M = Rand*dF_E;

% Find derivatives of homotopy function
dGy = M*N; 
dGt = M*((N_star - N_hat)*(A*y+b)); 

return
