function [Rand] = leverage_local_rand(y,t,N_star,N_hat,c)

% Purpose - to create a randomization matrix based on leverage scores.

% Inputs:
% y - current data point on patch
% t - current time step value
% N_star - based on parameters for start system
% N_hat - based on parameters for target system
% c - indice for entry of patch vector that is 1

% Set up A matrix to ignore information from entry with value 1 (from
% patching)
A = eye(4,4);
A = A(:,[1:c-1,c+1:end]);
b = zeros(4,1);
b(c) = 1;

% Set up system of equations for homotopy
N = (N_star*t + N_hat*(1-t))*A;
temp = N*y + (N_star*t + N_hat*(1-t))*b;
E = [temp(1,1) temp(2,1) temp(3,1); ...
    temp(4,1) temp(5,1) temp(6,1); ...
    temp(7,1) temp(8,1) temp(9,1)];

% Evaluate system of equations for homotopy
[~, dF_E] = evalfunc(E);

% Calculate the Jacobian
JF_E = dF_E*N;

% Start of calculation of leverage scores
% First, use efficient QR factorization of Jacobian
[Q,~,~] = qr(JF_E,0);

% Take the 2-norm of each row of Q
Q_norm = zeros(9,1);
Q_norm(1,1) = norm(Q(1,:),2);
Q_norm(2,1) = norm(Q(2,:),2);
Q_norm(3,1) = norm(Q(3,:),2);
Q_norm(4,1) = norm(Q(4,:),2);
Q_norm(5,1) = norm(Q(5,:),2);
Q_norm(6,1) = norm(Q(6,:),2);
Q_norm(7,1) = norm(Q(7,:),2);
Q_norm(8,1) = norm(Q(8,:),2);
Q_norm(9,1) = norm(Q(9,:),2);

% Sort rows of Q to find maximum leverage scores
% Record indices that correspond to row number of maximum leverage scores
[~,a] = sort(Q_norm,'descend');

% Set up entries of randomization matrix based on inverse of 
% the 2-norm of the corresponding Jacobian matrix row
Rand = zeros(3,9);
Rand(1,a(1)) = 1/norm(JF_E(a(1),:),2);
Rand(2,a(2)) = 1/norm(JF_E(a(2),:),2);
Rand(3,a(3)) = 1/norm(JF_E(a(3),:),2);