function [G, dGy, dGt] = orthog_patch_evalhom(y,t,Q,N_star,N_hat,v)

% Purpose - to evaulate the homotopy function based on current data

% Inputs:
% y - current data point on patch
% t - current time step value
% Q - random orthogonal matrix used for fixed randomization
% N_star - based on parameters for start system
% N_hat - based on parameters for target system
% v - data for orthogonal patching

% Set up A matrix based on orthogonal patch
A = null(v);

% Set up system of equations for homotopy
N = (N_star*t + N_hat*(1-t))*A;
temp = N*y + (N_star*t + N_hat*(1-t))*transpose(v);
E = [temp(1,1) temp(2,1) temp(3,1); ...
    temp(4,1) temp(5,1) temp(6,1); ...
    temp(7,1) temp(8,1) temp(9,1)];

% Evaluate system of equations for homotopy
[F, dF_E] = evalfunc(E);

% Set up homotopy function after randomization
G = [eye(3,3) Q]*F;
M = [eye(3,3) Q]*dF_E;

% Find derivatives of homotopy function
dGy = M*N;
dGt = M*((N_star - N_hat)*(A*y+transpose(v)));

return