function [Rand] = pinv_orthog_rand(y,t,N_star,N_hat,v)

% Purpose - to create a randomization matrix based on leverage scores.

% Inputs:
% y - current data point on patch
% t - current time step value
% N_star - based on parameters for start system
% N_hat - based on parameters for target system
% v - orthogonal patch data

% Set up A matrix based on orthogonal patch
A = null(v);

% Set up system of equations for homotopy
N = (N_star*t + N_hat*(1-t))*A;
temp = N*y + (N_star*t + N_hat*(1-t))*transpose(v);
E = [temp(1,1) temp(2,1) temp(3,1); ...
    temp(4,1) temp(5,1) temp(6,1); ...
    temp(7,1) temp(8,1) temp(9,1)];

% Evaluate system of equations for homotopy
[~, dF_E] = evalfunc(E);

% Find Jacobian
JF_E = dF_E*N;

% Calculate the SVD of the Jacobian
[U,S,~] = svd(JF_E,'econ');

% Set up randomization matrix based on inv(S)*U'
Rand = S\U';