function [Rand] = early_trunc_rand_6pt(y,c)

% Purpose - to create a randomization matrix based on leverage scores.

% Inputs:
% y - current data point on patch
% c - indice for entry of patch vector that is 1

temp = [y(1:c-1); 1; y(c:end)];

E = [temp(1,1) temp(2,1) temp(3,1); ...
    temp(4,1) temp(5,1) temp(6,1); ...
    temp(7,1) temp(8,1) temp(9,1)];

[~, dF_E] = evalfunc(E);
dF_E = dF_E(:,[1:c-1,c+1:end]);

% Start of calculation of leverage scores
% First, use efficient QR factorization of Jacobian
[Q,~,~] = qr(dF_E,0);
Q = Q(:,1:3);

% Take the 2-norm of each row of Q
Q_norm = zeros(9,1);
Q_norm(1,1) = norm(Q(1,:),2);
Q_norm(2,1) = norm(Q(2,:),2);
Q_norm(3,1) = norm(Q(3,:),2);
Q_norm(4,1) = norm(Q(4,:),2);
Q_norm(5,1) = norm(Q(5,:),2);
Q_norm(6,1) = norm(Q(6,:),2);
Q_norm(7,1) = norm(Q(7,:),2);
Q_norm(8,1) = norm(Q(8,:),2);
Q_norm(9,1) = norm(Q(9,:),2);

% Sort rows of Q to find maximum leverage scores
% Record indices that correspond to row number of maximum leverage scores
[~,a] = sort(Q_norm,'descend');

% Set up entries of randomization matrix based on inverse of 
% the 2-norm of the corresponding Jacobian matrix row
Rand = zeros(3,9);
Rand(1,a(1)) = 1/norm(dF_E(a(1),:),2);
Rand(2,a(2)) = 1/norm(dF_E(a(2),:),2);
Rand(3,a(3)) = 1/norm(dF_E(a(3),:),2);